@@ -8,7 +8,7 @@ package Net::Async::HTTP::Server::Request;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Carp;
 
@@ -37,6 +37,7 @@ sub new
 
       pending => [],
       is_done => 0,
+      is_closed => 0,
    }, $class;
 }
 
@@ -44,6 +45,26 @@ sub new
 
 =cut
 
+=head2 $is_closed = $request->is_closed
+
+Returns true if the underlying network connection for this request has already
+been closed. If this is the case, the application is free to drop the request
+object and perform no further processing on it.
+
+=cut
+
+sub _close
+{
+   my $self = shift;
+   $self->{is_closed} = 1;
+}
+
+sub is_closed
+{
+   my $self = shift;
+   return $self->{is_closed};
+}
+
 =head2 $method = $request->method
 
 Return the method name from the request header.
@@ -168,6 +189,8 @@ sub write
    my $self = shift;
    my ( $data ) = @_;
 
+   return if $self->{is_closed};
+
    $self->{is_done} and croak "This request has already been completed";
 
    push @{ $self->{pending} }, $data;
@@ -186,6 +209,8 @@ sub write_chunk
    my $self = shift;
    my ( $data ) = @_;
 
+   return if $self->{is_closed};
+
    $self->write( sprintf "%X$CRLF%s$CRLF", length $data, $data );
 }
 
@@ -199,6 +224,8 @@ sub done
 {
    my $self = shift;
 
+   return if $self->{is_closed};
+
    $self->{is_done} and croak "This request has already been completed";
 
    $self->{is_done} = 1;
@@ -215,6 +242,8 @@ sub write_chunk_eof
 {
    my $self = shift;
 
+   return if $self->{is_closed};
+
    $self->write( "0$CRLF$CRLF" );
    $self->done;
 }
