@@ -11,12 +11,24 @@ use warnings;
 use Net::Async::HTTP::Server::PSGI;
 use IO::Async::Loop;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 NAME
 
 C<Plack::Handler::Net::Async::HTTP::Server> - HTTP handler for Plack using L<Net::Async::HTTP::Server>
 
+=head1 SYNOPSIS
+
+ use Plack::Handler::Net::Async::HTTP::Server;
+
+ my $handler = Plack::Handler::Net::Async::HTTP::Server->new(
+    listen => [ ":8080" ],
+ );
+
+ sub psgi_app { ... }
+
+ $handler->run( \&psgi_app );
+
 =head1 DESCRIPTION
 
 This module allows L<Plack> to run a L<PSGI> application as a standalone
@@ -29,6 +41,47 @@ further information on environment etc.. is documented there.
 
 =cut
 
+=head1 METHODS
+
+=cut
+
+=head2 $handler = Plack::Handler::Net::Async::HTTP::Server->new( %args )
+
+Returns a new instance of a C<Plack::Handler::Net::Async::HTTP::Server>
+object. Takes the following named arguments:
+
+=over 4
+
+=item listen => ARRAY of STRING
+
+Reference to an array containing listen string specifications. Each string
+gives a port number and optional hostname, given as C<:port> or C<host:port>.
+
+=item server_ready => CODE
+
+Reference to code to invoke when the server is set up and listening, ready to
+accept connections. It is invoked with a HASH reference containing the
+following details:
+
+ $server_ready->( {
+    host            => HOST,
+    port            => SERVICE,
+    server_software => NAME,
+ } )
+
+=item socket => STRING
+
+Gives a UNIX socket path to listen on, instead of a TCP socket.
+
+=item queuesize => INT
+
+Optional. If provided, sets the C<listen()> queue size for creating listening
+sockets. If missing, a default of 10 is used.
+
+=back
+
+=cut
+
 sub new
 {
    my $class = shift;
@@ -38,7 +91,7 @@ sub new
    delete $opts{port};
 
    my $self = bless {
-      map { $_ => delete $opts{$_} } qw( listen server_ready socket ),
+      map { $_ => delete $opts{$_} } qw( listen server_ready socket queuesize ),
    }, $class;
 
    keys %opts and die "Unrecognised keys " . join( ", ", sort keys %opts );
@@ -46,12 +99,20 @@ sub new
    return $self;
 }
 
+=head2 $handler->run( $psgi_app )
+
+Creates the HTTP-listening socket or sockets, and runs the given PSGI
+application for received requests.
+
+=cut
+
 sub run
 {
    my $self = shift;
    my ( $app ) = @_;
 
    my $loop = IO::Async::Loop->new;
+   my $queuesize = $self->{queuesize} || 10;
 
    foreach my $listen ( @{ $self->{listen} } ) {
       my $httpserver = Net::Async::HTTP::Server::PSGI->new(
@@ -69,7 +130,7 @@ sub run
 
          my $socket = IO::Socket::UNIX->new(
             Local  => $path,
-            Listen => 10,
+            Listen => $queuesize,
          ) or die "Cannot listen on $path - $!";
 
          $httpserver->configure( handle => $socket );
@@ -81,8 +142,15 @@ sub run
             host     => $host,
             service  => $service,
             socktype => "stream",
+            queuesize => $queuesize,
 
-            on_notifier => sub { $self->{server_ready} and $self->{server_ready}->() },
+            on_notifier => sub {
+               $self->{server_ready}->( {
+                  host            => $host,
+                  port            => $service,
+                  server_software => ref $self,
+               } ) if $self->{server_ready};
+            },
 
             on_resolve_error => sub {
                die "Cannot resolve - $_[-1]\n";
